==> cocos2d-iphone-0.99.3-rc.tar.gz: cocos2d-iphone-0.99.3-rc/cocos2d/CCParticleExamples.h <==
/*
 * cocos2d for iPhone: http://www.cocos2d-iphone.org
 *
 * Copyright (c) 2008-2010 Ricardo Quesada
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 */


#import "CCPointParticleSystem.h"
#import "CCQuadParticleSystem.h"

//! A fire particle system
@interface CCParticleFire: CCPointParticleSystem
{
}
@end

//! A fireworks particle system
@interface CCParticleFireworks : CCPointParticleSystem
{
}
@end

//! A sun particle system
@interface CCParticleSun : CCPointParticleSystem
{
}
@end

//! A galaxy particle system
@interface CCParticleGalaxy : CCPointParticleSystem
{
}
@end

//! A flower particle system
@interface CCParticleFlower : CCPointParticleSystem
{
}
@end

//! A meteor particle system
@interface CCParticleMeteor : CCPointParticleSystem
{
}
@end

//! An spiral particle system
@interface CCParticleSpiral : CCPointParticleSystem
{
}
@end

//! An explosion particle system
@interface CCParticleExplosion : CCPointParticleSystem
{
}
@end

//! An smoke particle system
@interface CCParticleSmoke : CCPointParticleSystem
{
}
@end

//! An snow particle system
@interface CCParticleSnow : CCPointParticleSystem
{
}
@end

//! A rain particle system
@interface CCParticleRain : CCPointParticleSystem
{
}
@end

==> cocos2d-iphone-0.99.4-rc.tar.gz: cocos2d-iphone-0.99.4-rc/cocos2d/CCParticleExamples.h <==
/*
 * cocos2d for iPhone: http://www.cocos2d-iphone.org
 *
 * Copyright (c) 2008-2010 Ricardo Quesada
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 */


#import "CCPointParticleSystem.h"
#import "CCQuadParticleSystem.h"

//! A fire particle system
@interface CCParticleFire: CCQuadParticleSystem
{
}
@end

//! A fireworks particle system
@interface CCParticleFireworks : CCQuadParticleSystem
{
}
@end

//! A sun particle system
@interface CCParticleSun : CCQuadParticleSystem
{
}
@end

//! A galaxy particle system
@interface CCParticleGalaxy : CCQuadParticleSystem
{
}
@end

//! A flower particle system
@interface CCParticleFlower : CCQuadParticleSystem
{
}
@end

//! A meteor particle system
@interface CCParticleMeteor : CCQuadParticleSystem
{
}
@end

//! An spiral particle system
@interface CCParticleSpiral : CCQuadParticleSystem
{
}
@end

//! An explosion particle system
@interface CCParticleExplosion : CCQuadParticleSystem
{
}
@end

//! An smoke particle system
@interface CCParticleSmoke : CCQuadParticleSystem
{
}
@end

//! An snow particle system
@interface CCParticleSnow : CCQuadParticleSystem
{
}
@end

//! A rain particle system
@interface CCParticleRain : CCQuadParticleSystem
{
}
@end
